@@ -92,13 +92,13 @@ class Settings(dict):
             return self._rules_from_env(val)
         elif attr == 'priority':
             return dict(self._priority_from_env(val))
-        elif attr == 'wait_command':
+        elif attr in ('wait_command', 'history_limit', 'wait_slow_command'):
             return int(val)
         elif attr in ('require_confirmation', 'no_colors', 'debug',
                       'alter_history'):
             return val.lower() == 'true'
-        elif attr == 'history_limit':
-            return int(val)
+        elif attr == 'slow_commands':
+            return val.split(':')
         else:
             return val
 
