@@ -1,6 +1,9 @@
+from thefuck.specific.npm import npm_available
 from thefuck.utils import replace_argument, for_app, eager, get_closest
 from thefuck.specific.sudo import sudo_support
 
+enabled_by_default = npm_available
+
 
 def _get_wrong_command(script_parts):
     commands = [part for part in script_parts[1:] if not part.startswith('-')]
